@@ -2,8 +2,8 @@ from rest_framework import serializers
 
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedPartitionSerializer
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, Partition, PhysicalVolume
+    NestedPartitionSerializer, NestedVolumeGroupSerializer
+from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, LogicalVolume, VolumeGroup
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -42,24 +42,6 @@ class DriveSerializer(NetBoxModelSerializer):
         )
 
 
-class LinuxVolumeSerializer(serializers.ModelSerializer):
-    fs = NestedFilesystemSerializer(required=False, allow_null=True)
-
-    class Meta:
-        model = LinuxVolume
-        fields = (
-            "id",
-            "vg_name",
-            "lv_name",
-            "fs",
-            "path",
-            "description",
-            "created",
-            "last_updated",
-            "custom_fields",
-        )
-
-
 class PartitionSerializer(serializers.ModelSerializer):
     drive = NestedDriveSerializer(required=False, allow_null=True)
 
@@ -92,3 +74,36 @@ class PhysicalVolumeSerializer(serializers.ModelSerializer):
             "last_updated",
             "custom_fields",
         )
+
+
+class LogicalVolumeSerializer(serializers.ModelSerializer):
+    fs = NestedFilesystemSerializer(required=False, allow_null=True)
+    vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
+
+    class Meta:
+        model = LogicalVolume
+        fields = (
+            "id",
+            "vg",
+            "lv_name",
+            "fs",
+            "path",
+            "description",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
+
+
+class VolumeGroupSerializer(serializers.ModelSerializer):
+
+    class Meta:
+        model = VolumeGroup
+        fields = (
+            "id",
+            "vg_name",
+            "description",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
