@@ -24,7 +24,7 @@ class DriveFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = Drive
-        fields = ("size", "cluster", "virtual_machine")
+        fields = ("size", "cluster", "identifier", "virtual_machine", "description",)
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
@@ -32,5 +32,9 @@ class DriveFilter(NetBoxModelFilterSet):
             return queryset
         qs_filter = (
             Q(size__icontains=value)
+            | Q(cluster__icontains=value)
+            | Q(identifier__icontains=value)
+            | Q(virtual_machine__icontains=value)
+            | Q(description__icontains=value)
         )
         return queryset.filter(qs_filter)
