@@ -10,7 +10,7 @@ class PartitionFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = Partition
-        fields = ("drive", "device", "size")
+        fields = ("drive", "device", "size", "type")
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
