@@ -10,7 +10,7 @@ class PhysicalVolumeFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = PhysicalVolume
-        fields = ["partition"]
+        fields = ["partition", "pv_name"]
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
@@ -18,5 +18,6 @@ class PhysicalVolumeFilter(NetBoxModelFilterSet):
             return queryset
         qs_filter = (
             Q(partition__icontains=value)
+            | Q(pv_name__icontains=value)
         )
         return queryset.filter(qs_filter)
