@@ -106,7 +106,7 @@ class Migration(migrations.Migration):
             },
         ),
         migrations.CreateModel(
-            name="LinuxVolume",
+            name="VolumeGroup",
             fields=[
                 ("created", models.DateTimeField(auto_now_add=True, null=True)),
                 ("last_updated", models.DateTimeField(auto_now=True, null=True)),
@@ -119,10 +119,30 @@ class Migration(migrations.Migration):
                     ),
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("physical_volume", models.ForeignKey(on_delete=models.deletion.CASCADE,
-                                                      related_name="linux_physicalvolume",
-                                                      to="netbox_storage.physicalvolume")),
                 ("vg_name", models.CharField(max_length=255)),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("lv_name", "id"),
+            },
+        ),
+        migrations.CreateModel(
+            name="LogicalVolume",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("vg", models.ForeignKey(on_delete=models.deletion.CASCADE,
+                                         related_name="volumegroup_logicalvolume",
+                                         to="netbox_storage.volumegroup")),
                 ("lv_name", models.CharField(max_length=255)),
                 ("path", models.CharField(max_length=255)),
                 ("fs",
