@@ -1,4 +1,6 @@
+from django.core.exceptions import ValidationError
 from django.db import models
+from django.db.models import Sum
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
@@ -45,7 +47,7 @@ class Drive(NetBoxModel):
     def save(self, *args, **kwargs):
         is_already_implemented = Drive.objects.filter(id=self.pk).count()
         if is_already_implemented == 0:
-            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created")\
+            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created") \
                 .count()
 
             self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
@@ -95,6 +97,31 @@ class Partition(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/partition/'
 
+    def clean(self, *args, **kwargs):
+        total_allocated_space = Partition.objects.filter(drive=self.drive).aggregate(sum=Sum("size")).get("sum") or 0
+        current_partition_size = Partition.objects.filter(drive=self.drive, id=self.pk)\
+            .aggregate(sum=Sum("size")).get("sum") or 0
+        diff_to_allocated_space = self.size - current_partition_size
+        if diff_to_allocated_space > 0:
+            if total_allocated_space == self.drive.size:
+                raise ValidationError(
+                    {
+                        "size": f"The maximum Space of the hard drive was already allocated."
+                    }
+                )
+            if self.size > self.drive.size:
+                raise ValidationError(
+                    {
+                        "size": f"The size of the Partition is bigger than the size of the Hard Drive."
+                    }
+                )
+            if total_allocated_space + self.size > self.drive.size:
+                raise ValidationError(
+                    {
+                        "size": f"The size of the Partition is bigger than the size of the Hard Drive."
+                    }
+                )
+
     def physicalvolumes_count(self):
         return PhysicalVolume.objects.filter(partition=self).count()
 
@@ -114,10 +141,10 @@ class PhysicalVolume(NetBoxModel):
     )
 
     clone_fields = [
-            "partition",
-            "pv_name",
-            "description",
-        ]
+        "partition",
+        "pv_name",
+        "description",
+    ]
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
@@ -129,6 +156,30 @@ class PhysicalVolume(NetBoxModel):
         ordering = ("partition", "description")
 
 
+class VolumeGroup(NetBoxModel):
+    vg_name = models.CharField(
+        max_length=255,
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+        "vg_name",
+        "description",
+    ]
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:volumegroup", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return self.vg_name
+
+    class Meta:
+        ordering = ("vg_name", "description")
+
+
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
         unique=True,
@@ -151,19 +202,14 @@ class Filesystem(NetBoxModel):
         ordering = ("filesystem", "description")
 
 
-class LinuxVolume(NetBoxModel):
-    physical_volume = models.ForeignKey(
-        PhysicalVolume,
-        on_delete=models.CASCADE,
-        related_name="linux_physicalvolume",
-        verbose_name="Physical Volume",
-    )
-    vg_name = models.CharField(
-        max_length=255,
-    )
+class LogicalVolume(NetBoxModel):
+    vg = models.ForeignKey(VolumeGroup, on_delete=models.CASCADE, related_name='volumegroup_logicalvolume',)
     lv_name = models.CharField(
         max_length=255,
     )
+    size = models.PositiveIntegerField(
+        verbose_name="Size (GB)"
+    )
     path = models.CharField(
         max_length=255,
     )
@@ -179,19 +225,18 @@ class LinuxVolume(NetBoxModel):
     )
 
     clone_fields = [
-            "physical_volume",
-            "vg_name",
-            "lv_name",
-            "path",
-            "fs",
-            "description",
-        ]
+        "lv_name",
+        "size",
+        "path",
+        "fs",
+        "description",
+    ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
+        return reverse("plugins:netbox_storage:logicalvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"vg_{self.vg_name}-lv_{self.lv_name}"
+        return self.lv_name
 
     class Meta:
-        ordering = ("vg_name", "lv_name", "path")
+        ordering = ("lv_name", "description")
