@@ -1,6 +1,6 @@
 from extras.plugins import PluginTemplateExtension
 
-from netbox_storage.models import Drive, LinuxVolume
+from netbox_storage.models import Drive
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -15,7 +15,7 @@ class RelatedDrives(PluginTemplateExtension):
         # drive_table = RelatedDriveTable(
         #     data=drives
         # )
-        volumes = LinuxVolume.objects.all()
+        # volumes = LinuxVolume.objects.all()
         # exclude_drive_id = []
         # for volume in volumes.all():
         #     for drive in volume.drives.all():
@@ -35,7 +35,7 @@ class RelatedDrives(PluginTemplateExtension):
                 return self.render(
                     "netbox_storage/volume/windowsvolume_box.html",
                     extra_context={
-                        "volumes": volumes,
+                        # "volumes": volumes,
                         # "unmapped_drives": unmapped_drives,
                         "type": type(obj.platform),
                         # "display_volume": display_volume
